// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "UILabel.hpp"

using namespace Dawn;

void UILabel::getSelfQuads(
  const struct UIAlign alignment,
  UICanvas &ctx
) {
  std::vector<struct UIShaderQuad> quads;
  if(this->texture == nullptr || this->text.empty()) return;

  glm::vec4 quad;
  glm::vec2 pos = alignment.position;

  for(wchar_t c : text) {
    auto info = texture->getCharacterData(c);
    ctx.addQuad(
      {
        pos.x + info.offset.x,
        pos.y + info.offset.y,
        pos.x + info.size.x + info.offset.x,
        pos.y + info.size.y + info.offset.y
      },
      {
        info.quad.x,
        info.quad.y,
        info.quad.z,
        info.quad.w
      },
      COLOR_WHITE,
      UIShaderQuadStyle::FONT,
      texture->texture
    );
    pos += info.advance;
  }
}

std::shared_ptr<TrueTypeTexture> UILabel::getFont() {
  return this->texture;
}

std::wstring UILabel::getText() {
  return this->text;
}

void UILabel::setFont(std::shared_ptr<TrueTypeTexture> texture) {
  this->texture = texture;
}

void UILabel::setText(const std::wstring &text) {
  this->text = text;
}